Header — Glances 3.1.3 documentation

# Header

The header shows the hostname, OS name, release version, platform architecture IP addresses (private and public) and system uptime. Additionally, on GNU/Linux, it also shows the kernel version.

In client mode, the server connection status is also displayed.

Connected:

Disconnected:

If you are hosted on an `OpenStack` instance, some additional information can be displayed (AMI-ID, region).